@@ -26,13 +26,15 @@ use crate::model::{LanguageModel, TestDataLanguageModel};
 use crate::ngram::Ngram;
 use itertools::Itertools;
 use once_cell::sync::Lazy;
-use rayon::prelude::*;
 use std::collections::{HashMap, HashSet};
 use std::hash::Hash;
 use std::str::FromStr;
 use std::sync::RwLock;
 use strum::IntoEnumIterator;
 
+#[cfg(not(target_family = "wasm"))]
+use rayon::prelude::*;
+
 type BoxedLanguageModel = Box<dyn LanguageModel + Send + Sync>;
 type LazyLanguageModelMap = Lazy<RwLock<HashMap<Language, BoxedLanguageModel>>>;
 type StaticLanguageModelMap = &'static RwLock<HashMap<Language, BoxedLanguageModel>>;
@@ -92,7 +94,12 @@ impl LanguageDetector {
     }
 
     fn preload_language_models(&mut self, languages: &HashSet<Language>) {
-        languages.par_iter().for_each(|language| {
+        #[cfg(not(target_family = "wasm"))]
+        let languages_iter = languages.par_iter();
+        #[cfg(target_family = "wasm")]
+        let languages_iter = languages.iter();
+
+        languages_iter.for_each(|language| {
             self.load_language_models(self.unigram_language_models, language, 1);
             self.load_language_models(self.bigram_language_models, language, 2);
             self.load_language_models(self.trigram_language_models, language, 3);
@@ -183,12 +190,16 @@ impl LanguageDetector {
             1..6usize
         };
 
+        #[cfg(not(target_family = "wasm"))]
+        let ngram_length_range_iter = ngram_length_range.into_par_iter();
+        #[cfg(target_family = "wasm")]
+        let ngram_length_range_iter = ngram_length_range.into_iter();
+
         #[allow(clippy::type_complexity)]
         let all_probabilities_and_unigram_counts: Vec<(
             HashMap<Language, f64>,
             Option<HashMap<Language, u32>>,
-        )> = ngram_length_range
-            .into_par_iter()
+        )> = ngram_length_range_iter
             .filter(|i| character_count >= *i)
             .map(|ngram_length| {
                 self.look_up_language_models(&cleaned_up_text, ngram_length, &filtered_languages)
@@ -418,11 +429,15 @@ impl LanguageDetector {
 
         let mut language_counts = HashMap::<&Language, u32>::new();
 
-        for word in words.iter() {
-            for (characters, languages) in CHARS_TO_LANGUAGES_MAPPING.iter() {
+        for (characters, languages) in CHARS_TO_LANGUAGES_MAPPING.iter() {
+            let relevant_languages = filtered_languages
+                .intersection(languages)
+                .collect::<HashSet<_>>();
+
+            for word in words.iter() {
                 for character in characters.chars() {
                     if word.contains(character) {
-                        for language in languages.iter() {
+                        for language in relevant_languages.iter() {
                             self.increment_counter(&mut language_counts, language);
                         }
                     }
@@ -433,14 +448,11 @@ impl LanguageDetector {
         let languages_subset = language_counts
             .into_iter()
             .filter(|(_, count)| (*count as f64) >= half_word_count)
-            .map(|(language, _)| language)
+            .map(|(language, _)| language.clone())
             .collect::<HashSet<_>>();
 
         if !languages_subset.is_empty() {
-            filtered_languages
-                .into_iter()
-                .filter(|it| languages_subset.contains(&it))
-                .collect::<HashSet<_>>()
+            languages_subset
         } else {
             filtered_languages
         }
