@@ -73,7 +73,7 @@
 //!
 //! The [bar and box plots](https://github.com/pemistahl/lingua-rs/blob/main/ACCURACY_PLOTS.md)
 //! show the measured accuracy values for all three performed tasks: Single word detection,
-//! word pair detection and sentence detection. *Lingua* clearly outperforms its contender.
+//! word pair detection and sentence detection. *Lingua* clearly outperforms its contenders.
 //! Detailed statistics including mean, median and standard deviation values for each language
 //! and classifier are available in
 //! [tabular form](https://github.com/pemistahl/lingua-rs/blob/main/ACCURACY_TABLE.md) as well.
@@ -110,17 +110,17 @@
 //!
 //! ```toml
 //! [dependencies]
-//! lingua = "1.3.2"
+//! lingua = "1.4.0"
 //! ```
 //!
 //! By default, this will download the language model dependencies for all 75 supported languages,
-//! a total of approximately 120 MB. If your bandwidth or hard drive space is limited, or you simply
+//! a total of approximately 100 MB. If your bandwidth or hard drive space is limited, or you simply
 //! do not need all languages, you can specify a subset of the language models to be downloaded as
 //! separate features in your `Cargo.toml`:
 //!
 //! ```toml
 //! [dependencies]
-//! lingua = { version = "1.3.2", default-features = false, features = ["french", "italian", "spanish"] }
+//! lingua = { version = "1.4.0", default-features = false, features = ["french", "italian", "spanish"] }
 //! ```
 //!
 //! ## 7. How to use?
@@ -281,12 +281,18 @@ mod model;
 mod ngram;
 mod writer;
 
+#[cfg(target_family = "wasm")]
+mod wasm;
+
 pub use builder::LanguageDetectorBuilder;
 pub use detector::LanguageDetector;
 pub use isocode::{IsoCode639_1, IsoCode639_3};
 pub use language::Language;
 pub use writer::{LanguageModelFilesWriter, TestDataFilesWriter};
 
+#[cfg(target_family = "wasm")]
+pub use wasm::LanguageDetectorBuilder as WasmLanguageDetectorBuilder;
+
 #[cfg(test)]
 use regex::Regex;
 
